@@ -56,8 +56,10 @@ def load_and_replace(path, replacements):
 def on_create(a):
     if isinstance(a.region, (list, tuple)):
         a.region = a.region[0]
+    print(f'Setting up in directory: {a.path}')
     directories = ['chalicelib/libs/', 'chalicelib/static/', 'chalicelib/templates/', '.chalice/']
-    for d  in directories:
+    for d in directories:
+        print(f'Making directory {d}')
         p = os.path.join(a.path, d)
         os.makedirs(p, exist_ok=True)
 
@@ -67,6 +69,7 @@ def on_create(a):
     cm_use_magic = ""
     if a.options is not None:
         if 'magic' in a.options:
+            print('Including libmagic in chalicelib/libs/')
             magic_path = os.path.join(a.path, 'chalicelib/libs/')
             copy_tree(os.path.join(assets_dir, 'magic'), magic_path)
             cm_use_magic = ", magic"
@@ -80,12 +83,14 @@ else:
     # Running locally, use system version of magic
     magic = Magic(mime=True)"""
 
+    print('Writing app.py')
     with open(os.path.join(a.path, 'app.py'), 'w') as f:
         f.write(load_and_replace(os.path.join(assets_dir, 'app.py'),
                                  {'<app_name>': a.name,
                                   '<use_magic>': use_magic,
                                   '<cm_use_magic>': cm_use_magic}))
     
+    print('Writing .chalice/config.json')
     with open(os.path.join(a.path, '.chalice/config.json'), 'w') as f:
         layers = get_layers(a.region)
         layers = '"' + '",\n"'.join(layers) + '"'
